atomate Changelog — atomate 0.3 documentation

# atomate Changelog

v0.3

- Raman workflow (K. Mathew)
- Gibbs workflow (K. Mathew)
- More efficient task builder (S. Ong)
- tag workflows and add_trackers powerups (A. Jain, A. Faghaninia)
- refactor elastic workflow (K. Mathew)
- bugfixes and tools package (K. Mathew)

v0.21

- Lammps workflows and packmol support (K. Mathew)
- Rework some of the RunVaspFake code (K. Mathew)
- Fixes to elastic workflow (J. Montoya)
- Minor refactoring (K. Mathew)
- Minor MD workflow updates (M. Aykol)
- Fix builder for HSE gap and add chemsys
- WF metadata powerup
- Minor bug fixes and misc. improvements (K. Mathew, J. Montoya, A. Faghaninia)

v0.2

- BoltzTraP transport workflows
- major builder improvements (merge multiple collections, progressbar, config, more...)
- use FrozenJobErrorHandler by default
- add basic configuration overrides for preset workflows
- misc improvements and bugfixes
- py3 compatibility fixes (K. Mathew)

v0.1

- add some builders
- elastic + piezo workflows (J. Montoya + S. Dwaraknath)
- minor doc improvements (A. Faghaninia)
- misc code improvements and bug fixes, plus upgrades for new pymatgen

v0.0.3

- initial release (A. Jain, S.P. Ong, K. Mathew, M. Aykol)